@@ -1,33 +1,35 @@
 /* glpsol.c */
 
 /*----------------------------------------------------------------------
--- This file is a part of the GLPK package.
+-- Copyright (C) 2000, 2001, 2002 Andrew Makhorin <mao@mai2.rcnet.ru>,
+--               Department for Applied Informatics, Moscow Aviation
+--               Institute, Moscow, Russia. All rights reserved.
 --
--- Copyright (C) 2000, 2001 Andrew Makhorin <mao@mai2.rcnet.ru>,
---                          Department for Applied Informatics,
---                          Moscow Aviation Institute, Moscow, Russia.
---                          All rights reserved.
+-- This file is a part of GLPK (GNU Linear Programming Kit).
 --
--- This code is free software; you can redistribute it and/or modify
--- it under the terms of the GNU General Public License as published by
--- the Free Software Foundation; either version 2 of the License, or
--- (at your option) any later version.
+-- GLPK is free software; you can redistribute it and/or modify it
+-- under the terms of the GNU General Public License as published by
+-- the Free Software Foundation; either version 2, or (at your option)
+-- any later version.
 --
--- This software is distributed "as is" in the hope that it will be
--- useful, but WITHOUT ANY WARRANTY; without even the implied warranty
--- of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
--- General Public License for more details.
+-- GLPK is distributed in the hope that it will be useful, but WITHOUT
+-- ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+-- or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
+-- License for more details.
 --
 -- You should have received a copy of the GNU General Public License
--- along with this program; if not, write to the Free Software
--- Foundation, 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
+-- along with GLPK; see the file COPYING. If not, write to the Free
+-- Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
+-- 02111-1307, USA.
 ----------------------------------------------------------------------*/
 
 #include <stdlib.h>
 #include <string.h>
 #include <time.h>
 #include "glpk.h"
-#include "glpset.h"
+#include "glplib.h"
+
+#define error print
 
 /*----------------------------------------------------------------------
 -- This program is a stand-alone LP/MIP solver. For pure LP problems
@@ -36,7 +38,7 @@
 -- based on the revised simplex method is used.
 ----------------------------------------------------------------------*/
 
-static char *version = "GLPSOL -- GLPK LP/MIP Solver, Version 3.0.4";
+static char *version = "GLPSOL -- GLPK LP/MIP Solver, Version 3.0.5";
 
 static char *in_fname = NULL;
 /* name of the input text file */
@@ -218,7 +220,8 @@ static void display_help(char *my_name)
 
 static void display_version(void)
 {     print("%s", version);
-      print("Copyright (C) 2000, 2001 Andrew Makhorin <mao@gnu.org>");
+      print("Copyright (C) 2000, 2001, 2002 Andrew Makhorin <mao@gnu.or"
+         "g>");
       print("This program is free software; you may redistribute it und"
          "er the terms of");
       print("the GNU General Public License. This program has absolutel"
@@ -449,7 +452,8 @@ int main(int argc, char *argv[])
       print("Time used: %.1f secs",
          (double)(clock() - t_start) / (double)CLOCKS_PER_SEC);
       print("Memory used: %.1fM (%d bytes)",
-         (double)mem_tpeak / (double)1000000, mem_tpeak);
+         (double)get_env_ptr()->mem_tpeak / (double)1000000,
+         get_env_ptr()->mem_tpeak);
       /* write problem solution found by the solver */
       if (out_fname != NULL && glp_print_soln(lp, out_fname) != 0)
       {  error("Unable to write problem solution");
